
History
=======

1.1 (2017-03-01)
----------------

- Use ``yafowil.utils.entry_point`` decorator.
  [rnix, 2016-06-28]

- Raise ``ValueError`` in ``location_extractor`` if malformed request is
  received.
  [rnix]

1.0 (2015-01-23)
----------------

- Make it work.
  [rnix]
